#
# spec file for package ghc-fgl
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name fgl
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        5.6.0.0
Release:        6.2
Summary:        Martin Erwig's Functional Graph Library
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
An inductive representation of manipulating graph data structures.

Original website can be found at
<http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog

%changelog
* Thu Apr 12 2018 psimons@suse.com
- Update fgl to version 5.6.0.0.
  A more detailed change log is not available.
* Tue Mar  7 2017 psimons@suse.com
- Update to version 5.5.3.1 with cabal2obs.
* Fri Jul 22 2016 psimons@suse.com
- Update to version 5.5.3.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 5.5.2.3 revision 0 with cabal2obs.
  This update obsoletes ghc-fgl-rpmlintrc.
* Sat Sep 26 2015 peter.trommler@ohm-hochschule.de
- remove dependency on mtl
* Sun Sep 13 2015 mimi.vx@gmail.com
- update to 5.5.2.3
  * Ensure firing of specialised rules for `PatriciaTree`.
  * Better way of only creating `NFData` instances when possible.
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 5.5.2.1
  * Only create `NFData` instances for GHC >= 7.4.1.
  * Documentation, clean-up and refactoring of various parts of the
  library.
  - As part of this, various types now have instances for classes
    like `Show`, `Eq`, `Ord`, `NFData`, etc. where applicable.
  - In particular, the various options for use with depth-first
    search and shortest path queries was documented by David
    Luposchainsky.
  * Addition of a proper test-suite.  So far it covers the
  `Data.Graph.Inductive.Graph` module and all
  `Data.Graph.Inductive.Query.*` modules except for `Monad`.
  * Arbitrary instances for the two graph types are now available in the
  new `fgl-arbitrary` sub-package.
  * Now depends solely on the `transformers` library rather than `mtl`.
  * Potentially breaking changes:
    These changes are those where the behaviour was un-specified or
    didn't match the documentation.
  - `nodeRange` and `nodeRangeM` for the various graph data
    structures erroneously returned `(0,0)` for empty graphs (making
    them indistinguishable from graphs containing the single node
    `0`).  They now match the default implementation of throwing an
    error.
  - The behaviour of `delLEdge` when dealing with multiple edges was
    unspecified; it now deletes only a single edge and the new
    function `delAllLEdge` deletes all edges matching the one
    provided.
  - Creating sub-graphs by `Node`- and `Context`-filtering as well
    as induced by a set of `Node`s.
  - Graph condensation (i.e. graph of
    strongly-connected-components).
  - Various edge- and neighbor-based helper functions.
  * The graph types now have `Generic` instances thanks to Piotr
  Mlodawski.
  * The `OrdGr` wrapper by Trevor Cook allows performing `Ord`-based
  comparisons on graphs.
* Mon Apr 13 2015 mimi.vx@gmail.com
- update to 5.5.1.0
  * Support added for GHC 7.10 by Herbert Valerio Riedel.
  * Additional DFS query functions added by Conrad Parker.
  * Repository location changed to GitHub.
  * Code cleanup:
    Data.Set from the containers library.
    Remove usage of data type contexts.
    Use newtypes where applicable.
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- update to 5.5.0.1 for Haskell Platform 2014.2.0.0
  * fixes for Tree and PatriciaTree classes
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Fri Jan  4 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 template for spec file
* Tue May 29 2012 peter.trommler@ohm-hochschule.de
- added copyright notice
* Sat Dec 31 2011 peter.trommler@ohm-hochschule.de
- Added arch.
* Sat Dec 31 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
